<?php

namespace Drupal\file_compressor_field\Plugin\FileCompressor;

use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\Password\PasswordGeneratorInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\file_compressor_field\Plugin\FileCompressorBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Implements GZip compressor for File Compressor field.
 *
 * @FileCompressor(
 *   id = "gzip_zlib",
 *   admin_label = @Translation("GZip (Zlib)"),
 *   extension = "tar.gz"
 * )
 */
class FileCompressorGZip extends FileCompressorBase implements ContainerFactoryPluginInterface {

  /**
   * The file system service.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected $fileSystem;

  /**
   * The password generator service.
   *
   * @var \Drupal\Core\Password\PasswordGeneratorInterface
   */
  protected $passwordGenerator;

  /**
   * Constructs a new FileCompressorGZip object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\File\FileSystemInterface $file_system
   *   The file system service.
   * @param \Drupal\Core\Password\PasswordGeneratorInterface $password_generator
   *   The password generator service.
   */
  final public function __construct(array $configuration,
                              $plugin_id,
                              $plugin_definition,
                              FileSystemInterface $file_system,
                              PasswordGeneratorInterface $password_generator) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->fileSystem = $file_system;
    $this->passwordGenerator = $password_generator;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container,
                                array $configuration,
                                $plugin_id,
                                $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('file_system'),
      $container->get('password_generator')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function generateCompressedFile($file_uri, $files) {
    $full_file_uri = $this->fileSystem->realpath($file_uri);
    $tar = new \Archive_Tar($full_file_uri, 'gz');
    $tmp = 'temporary://file_compressor_field' . time() . $this->passwordGenerator->generate();
    $this->fileSystem->mkdir($tmp);
    foreach ($files as $file) {
      $this->fileSystem->copy($file, $tmp, FileSystemInterface::EXISTS_REPLACE);
    }
    $tar->createModify($tmp, '', $tmp);
    $this->fileSystem->deleteRecursive($tmp);

    return TRUE;
  }

}
